#
# spec file for package snack
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           snack
BuildRequires:  alsa-devel
BuildRequires:  libvorbis-devel
BuildRequires:  tk-devel
Summary:        Sound Extension for Tcl/Tk
License:        GPL-2.0-or-later
Group:          Development/Libraries/Tcl
Version:        2.2.10
Release:        216.1
Requires:       tcl
Requires:       tk
URL:            http://www.speech.kth.se/snack
Source0:        %{name}%{version}.tar.bz2
Source1:        snack-rpmlintrc
Patch0:         snack.patch
Patch1:         snack-alsa.patch
Patch2:         snack-CVE-2012-6303.patch
Patch3:         snack-tk-libs.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Snack provides commands to play, record, process, and visualize sound.
It supports various file formats such as WAV, AU, AIFF, and MP3.

With Snack, you can easily create sound applications with Tcl/Tk or
Python or extend existing programs with sound capabilities.

The documentation is located under /usr/share/doc/packages/snack There
is also a 'demos' subdirectory which contains examples for Tcl/Tk and
Python.



Authors:
--------
    Kåre Sjölander <kare@speech.kth.se>

%define INSTALL install -m755 -s
%define INSTALL_SCRIPT install -m755
%define INSTALL_DIR install -d -m755
%define INSTALL_DATA install -m644

%prep
%setup -q -n %{name}%{version}
%patch -P 0
%patch -P 1
%patch -P 2 -p 1
%patch -P 3
chmod 644 BSD.txt changes README COPYING doc/* ext/*
chmod 755 ext/configure

%build
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing -Wno-unused-variable -Wno-unused-but-set-variable"
cd unix
./configure \
    --prefix=%_prefix \
    --libdir=%_libdir \
    --with-tcl=%_libdir \
    --with-tk=%_libdir \
    --with-ogg-include=%_includedir \
    --with-ogg-lib=%_libdir \
    --enable-alsa
make OPTFLAGS="$CFLAGS"

%install
%{INSTALL_DIR} %buildroot%_libdir
cd unix
make  install \
	DESTDIR=%buildroot \
	SNACK_INSTALL_PATH=%tclscriptdir
# We don't install the headers, so we don't need the stubs lib
rm -f %buildroot/%_libdir/libsnack*.a

%clean
rm -rf %buildroot

%files
%defattr(-, root, root,-)
%_libdir/lib*
%defattr(644, root, root, 755)
%doc BSD.txt changes README COPYING doc/* ext
%tclscriptdir/*

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Jun 17 2021 Reinhard Max <max@suse.com>
- Disable the Python binding, because it only supports Python 2.
- Remove unneeded build dependencies (snack-tk-libs.patch).
* Fri Nov  3 2017 max@suse.com
- bnc#793860: CVE-2012-6303: heap based overflow:
  snack-CVE-2012-6303.patch
- Drop the demos, they violate too many rpmlint rules.
* Mon Jan 11 2010 max@suse.de
- Fix build on Factory and SLES10.
* Tue Nov  3 2009 max@suse.de
- Adopt patch from other distros to fix and re-enable ALSA support
  (snack-alsa.patch).
* Fri Oct  2 2009 max@suse.de
- Fix loading of libsnack by removing the rest of the MP3-related
  symbols.
* Wed Jun  3 2009 max@suse.de
- Don't build the MP3 decoder.
* Fri May 25 2007 max@suse.de
- Make rpmlint happy.
* Mon May 22 2006 max@suse.de
- New version: 2.2.10
- Improved MP3 format handling
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jul 28 2005 max@suse.de
- Use OSS, because ALSA support is incomplete and unstable.
- Moved the script library to /usr/share/tcl .
* Fri Apr 22 2005 max@suse.de
- Don't build with multiple compile jobs.
* Tue Feb 15 2005 ro@suse.de
- added python requires
* Tue Jan 25 2005 max@suse.de
- New version: 2.2.9
* Thu Nov 25 2004 ro@suse.de
- remove local macro for python_site
* Mon Jul 12 2004 max@suse.de
- New version: 2.2.7
* Thu Mar  4 2004 max@suse.de
- New version: 2.2.4
* Fri Feb  6 2004 max@suse.de
- Impoved ALSA support (snack-alsa.patch).
- Fixed reading from files on 64bit platforms (snack-64bit.patch).
- Added -fno-strict-aliasing to CFLAGS.
* Thu Oct 30 2003 max@suse.de
- Removed the unnecessary binary tclkit from the source tarball
  making it (and the resulting rpm) about 1MB smaller.
* Thu Oct 30 2003 max@suse.de
- New version: 2.2.3
- Using ALSA instead of OSS.
- Building as non-root user.
* Mon Jul 28 2003 ro@suse.de
- added tk-devel to neededforbuild
* Tue May 13 2003 max@suse.de
- Fixed building of libsnackogg.so.
* Mon May 12 2003 max@suse.de
- New version: 2.2.2.
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <xshared> to <x-devel-packages>
- changed neededforbuild <xdevel> to <>
* Mon Apr 15 2002 max@suse.de
- New version 2.1.6
* Wed Oct 31 2001 max@suse.de
- enabled support for Ogg bistreams and Vorbis audio compression.
* Wed Aug 15 2001 max@suse.de
- new version: 2.1.3
- changed RPM group to Development/Libraries/Tcl
* Fri Mar 30 2001 max@suse.de
- added xshared to #neededforbuild
* Thu Mar 15 2001 max@suse.de
- new version 2.0.7
* Fri Mar  9 2001 max@suse.de
- new package snack2.0.6
- building with buildroot
- supports Tcl/Tk and Python
- No hard dependency on Python, because Python support is just a
  wrapper around the Tcl extension and people who want to use it
  with Python will have installed Python anyway
- added tcl.m4 from Tcl/Tk to be able to re-create 'configure'
